micro-onos running in nightly test fix

Change-Id: I605ecdf629c3ce79570a3e691c0fa0dc303d6210
diff --git a/TestON/JenkinsFile/MasterTrigger.groovy b/TestON/JenkinsFile/MasterTrigger.groovy
index e3d26fe..01ceb6a 100644
--- a/TestON/JenkinsFile/MasterTrigger.groovy
+++ b/TestON/JenkinsFile/MasterTrigger.groovy
@@ -356,15 +356,15 @@
 }
 
 // Initialize the environment Setup for the onos and OnosSystemTest
-def envSetup( onos_branch, test_branch, onos_tag, jobOn, manuallyRun, nodeLabel ){
+def envSetup( onos_branch, test_branch, onos_tag, category, manuallyRun, nodeLabel ){
     // to setup the environment using the bash script
-    stage( "Environment Setup: " + onos_branch + "-" + nodeLabel + "-" + jobOn ) {
-        // after env: ''' + borrow_mn( jobOn ) + '''
+    stage( "Environment Setup: " + onos_branch + "-" + nodeLabel + "-" + category ) {
+        // after env: ''' + borrow_mn( category ) + '''
         sh script: '''#!/bin/bash -l
         set +e
         . ~/.bashrc
         env
-        ''' + preSetup( onos_branch, test_branch, onos_tag, manuallyRun, jobOn ), label: "Repo Setup", returnStdout: false
+        ''' + preSetup( onos_branch, test_branch, onos_tag, manuallyRun, category ), label: "Repo Setup", returnStdout: false
         if ( category != "MO" ){
             sh script: postSetup( onos_branch, test_branch, onos_tag, manuallyRun ), label: "Install Bazel", returnStdout: false
             generateKey()